Skip to contents

This function calculates the expected value of partially perfect information, i.e. the percentage by which we could reduce the variance of the final outcome if we knew this one parameter (or several interdependent parameters) perfectly.

Usage

compute_evppi(
  p,
  global_para,
  city_para,
  city_outcomes,
  nsamples,
  individual_para = TRUE
)

Arguments

p

input parameter index

global_para

list of global input parameters that are the same across all cities

city_para

list of city specific input parameters

nsamples

number of samples

individual_para

whether each parameter is to be considered individually or not

city_outcome

list of outcomes for a specific city

Value

list of of EVPPI values for specific city

Details

The function performs the following steps:

  • extract the parameter / parameters of interest for which the EVPPI value is to be calculated

  • loop through the various outcomes :

    • calculate the EVPPI value for each outcome using the evppivar() function from https://github.com/chjackson/voi

    • calculate the percentage of variance in the outcome we could reduce were we to know the input parameter / parameters perfectly.