EVPPI wrapper function for total population YLLs by sex
call_evppi_sex.RdThis function gets the ithim results into the correct format and calls the compute_evppi() script
to calculate the EVPPIs for all input parameters and required outcomes and scenarios split by sex.
Usage
call_evppi_sex(
voi_data_all_sex_df,
parameter_samples,
outcome_voi_list,
outcome,
cities,
voi_add_sum,
NSCEN,
NSAMPLES,
scenario_names,
evppi_df
)Arguments
- voi_data_all_sex_df
dataframe containing all outcomes by sex
- parameter_samples
table containing all the input parameter variables for the different model runs for all cities
- outcome_voi_list
vector detailing the outcomes to be considered in the VoI analysis
- outcome
total yll outcome for all outcome age categories per city and scenario and disease combination, also combined city result (sum)
- cities
vector of cities
- voi_add_sum
if the sum of YLLs across all disease outcomes is to be considered
- NSCEN
number of scenarios (not incl. baseline)
- NSAMPLES
number of times the model was run for each city
- scenario_names
gives the names of the scenarios (incl baseline)
- evppi_df
outcome dataframe containing voi analysis for total yll across all age and sex categories
Value
a list containing the following elements:
evppi_ex_df dataframe containing all EVPPI outcomes for all sex categories and all cities
sex_cat vector with both sexes
evppi_city_list_all_sex list where each list entry is a dataframe containing all EvPPI outcomes for all sex categories for one city
Details
The function performs the following steps:
create a vector containing the global parameters but not including the emission inventory parameters as they are not independent of each other
loop through the cities:
extract the city specific parameters (excluding the CO2 and PM emission inventory parameters)
loop through the two sexes:
extract the outcomes of interest for each scenario using the outcome_voi_list
if voi_add_sum == TRUE, calculate the total YLLs by summing across all diseases in the outcome_voi_list - this only makes sense if the diseases in the outcome_voi_list are independent of each other
call the
compute_evppi()function to calculate the expected values of partially perfect information (EVPPI) for all parameters and diseases of interest
if NSAMPLES >= 1000 then also calculate the EVPPI values for the emission inventory parameters by looping through both sexes